FrequencySpace
==============

.. currentmodule:: spdcalc.spdcalc

.. autoclass:: FrequencySpace
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~FrequencySpace.from_sum_diff_frequency_space
      ~FrequencySpace.from_wavelength_space
      ~FrequencySpace.set_resolution
      ~FrequencySpace.to_sum_diff_frequency_space
      ~FrequencySpace.to_wavelength_space

   .. rubric:: Methods Documentation

   .. automethod:: from_sum_diff_frequency_space
   .. automethod:: from_wavelength_space
   .. automethod:: set_resolution
   .. automethod:: to_sum_diff_frequency_space
   .. automethod:: to_wavelength_space
